pub struct ChangeGateFollowup {
pub followup_id: String,
pub gate_id: String,
pub actor: String,
pub outcome: i32,
pub note: Option<String>,
pub details: Option<Struct>,
pub recorded_at: Option<Timestamp>,
}Fields
followup_id: Stringgate_id: Stringactor: Stringoutcome: i32note: Option<String>details: Option<Struct>recorded_at: Option<Timestamp>Implementations
Sourceimpl ChangeGateFollowup
impl ChangeGateFollowup
Sourcepub fn outcome(&self) -> FollowupOutcome
pub fn outcome(&self) -> FollowupOutcome
Returns the enum value of outcome, or the default if the field is set to an invalid enum value.
Sourcepub fn set_outcome(&mut self, value: FollowupOutcome)
pub fn set_outcome(&mut self, value: FollowupOutcome)
Sets outcome to the provided enum value.