pub struct EvalMetric {
pub name: String,
pub slug: String,
pub score: f64,
pub threshold: Option<f64>,
pub direction: i32,
pub weight: Option<f64>,
}Fields
name: Stringslug: Stringscore: f64threshold: Option<f64>direction: i32weight: Option<f64>Implementations
Sourceimpl EvalMetric
impl EvalMetric
Sourcepub fn direction(&self) -> MetricDirection
pub fn direction(&self) -> MetricDirection
Returns the enum value of direction, or the default if the field is set to an invalid enum value.
Sourcepub fn set_direction(&mut self, value: MetricDirection)
pub fn set_direction(&mut self, value: MetricDirection)
Sets direction to the provided enum value.